<a id="mypy-boto3-route53domains"></a>

# mypy-boto3-route53domains

[![PyPI - mypy-boto3-route53domains](https://img.shields.io/pypi/v/mypy-boto3-route53domains.svg?color=blue)](https://pypi.org/project/mypy-boto3-route53domains)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-route53domains.svg?color=blue)](https://pypi.org/project/mypy-boto3-route53domains)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-route53domains?color=blue)](https://pypistats.org/packages/mypy-boto3-route53domains)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Route53Domains 1.18.45](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/route53domains.html#Route53Domains)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.3.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-route53domains docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53domains/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-route53domains](#mypy-boto3-route53domains)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `Route53Domains` service.

```bash
python -m pip install boto3-stubs[route53domains]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[route53domains]` in your environment:
  `python -m pip install 'boto3-stubs[route53domains]'`

Both type checking and auto-complete should work for `Route53Domains` service.
No explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[route53domains]` in your environment:
  `python -m pip install 'boto3-stubs[route53domains]'`

Both type checking and auto-complete should work for `Route53Domains` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[route53domains]` in your environment:
  `python -m pip install 'boto3-stubs[route53domains]'`
- Run `mypy` as usual

Type checking should work for `Route53Domains` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[route53domains]` in your environment:
  `python -m pip install 'boto3-stubs[route53domains]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Route53Domains` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`Route53DomainsClient` provides annotations for
`boto3.client("route53domains")`.

```python
import boto3

from mypy_boto3_route53domains import Route53DomainsClient

client: Route53DomainsClient = boto3.client("route53domains")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: Route53DomainsClient = session.client("route53domains")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_route53domains.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_route53domains import Route53DomainsClient
from mypy_boto3_route53domains.paginator import (
    ListDomainsPaginator,
    ListOperationsPaginator,
    ViewBillingPaginator,
)

client: Route53DomainsClient = boto3.client("route53domains")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_domains_paginator: ListDomainsPaginator = client.get_paginator("list_domains")
list_operations_paginator: ListOperationsPaginator = client.get_paginator("list_operations")
view_billing_paginator: ViewBillingPaginator = client.get_paginator("view_billing")
```

<a id="literals"></a>

### Literals

`mypy_boto3_route53domains.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_route53domains.literals import (
    ContactTypeType,
    CountryCodeType,
    DomainAvailabilityType,
    ExtraParamNameType,
    ListDomainsPaginatorName,
    ListOperationsPaginatorName,
    OperationStatusType,
    OperationTypeType,
    ReachabilityStatusType,
    TransferableType,
    ViewBillingPaginatorName,
    ServiceName,
)

def check_value(value: ContactTypeType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_route53domains.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_route53domains.type_defs import (
    AcceptDomainTransferFromAnotherAwsAccountRequestRequestTypeDef,
    AcceptDomainTransferFromAnotherAwsAccountResponseTypeDef,
    BillingRecordTypeDef,
    CancelDomainTransferToAnotherAwsAccountRequestRequestTypeDef,
    CancelDomainTransferToAnotherAwsAccountResponseTypeDef,
    CheckDomainAvailabilityRequestRequestTypeDef,
    CheckDomainAvailabilityResponseTypeDef,
    CheckDomainTransferabilityRequestRequestTypeDef,
    CheckDomainTransferabilityResponseTypeDef,
    ContactDetailTypeDef,
    DeleteTagsForDomainRequestRequestTypeDef,
    DisableDomainAutoRenewRequestRequestTypeDef,
    DisableDomainTransferLockRequestRequestTypeDef,
    DisableDomainTransferLockResponseTypeDef,
    DomainSuggestionTypeDef,
    DomainSummaryTypeDef,
    DomainTransferabilityTypeDef,
    EnableDomainAutoRenewRequestRequestTypeDef,
    EnableDomainTransferLockRequestRequestTypeDef,
    EnableDomainTransferLockResponseTypeDef,
    ExtraParamTypeDef,
    GetContactReachabilityStatusRequestRequestTypeDef,
    GetContactReachabilityStatusResponseTypeDef,
    GetDomainDetailRequestRequestTypeDef,
    GetDomainDetailResponseTypeDef,
    GetDomainSuggestionsRequestRequestTypeDef,
    GetDomainSuggestionsResponseTypeDef,
    GetOperationDetailRequestRequestTypeDef,
    GetOperationDetailResponseTypeDef,
    ListDomainsRequestRequestTypeDef,
    ListDomainsResponseTypeDef,
    ListOperationsRequestRequestTypeDef,
    ListOperationsResponseTypeDef,
    ListTagsForDomainRequestRequestTypeDef,
    ListTagsForDomainResponseTypeDef,
    NameserverTypeDef,
    OperationSummaryTypeDef,
    PaginatorConfigTypeDef,
    RegisterDomainRequestRequestTypeDef,
    RegisterDomainResponseTypeDef,
    RejectDomainTransferFromAnotherAwsAccountRequestRequestTypeDef,
    RejectDomainTransferFromAnotherAwsAccountResponseTypeDef,
    RenewDomainRequestRequestTypeDef,
    RenewDomainResponseTypeDef,
    ResendContactReachabilityEmailRequestRequestTypeDef,
    ResendContactReachabilityEmailResponseTypeDef,
    ResponseMetadataTypeDef,
    RetrieveDomainAuthCodeRequestRequestTypeDef,
    RetrieveDomainAuthCodeResponseTypeDef,
    TagTypeDef,
    TransferDomainRequestRequestTypeDef,
    TransferDomainResponseTypeDef,
    TransferDomainToAnotherAwsAccountRequestRequestTypeDef,
    TransferDomainToAnotherAwsAccountResponseTypeDef,
    UpdateDomainContactPrivacyRequestRequestTypeDef,
    UpdateDomainContactPrivacyResponseTypeDef,
    UpdateDomainContactRequestRequestTypeDef,
    UpdateDomainContactResponseTypeDef,
    UpdateDomainNameserversRequestRequestTypeDef,
    UpdateDomainNameserversResponseTypeDef,
    UpdateTagsForDomainRequestRequestTypeDef,
    ViewBillingRequestRequestTypeDef,
    ViewBillingResponseTypeDef,
)

def get_structure() -> AcceptDomainTransferFromAnotherAwsAccountRequestRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-route53domains` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-route53domains docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53domains/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
